//[mahjong-utils](../../../index.md)/[mahjongutils.hanhu](../index.md)/[ParentPoint](index.md)/[ron](ron.md)

# ron

[common]\
val [ron](ron.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

荣和点数
